@@ -2,9 +2,7 @@ package DBIx::Class::Helper::TableSample;
 
 # ABSTRACT: Add support for tablesample clauses
 
-use v5.10.1;
-
-use strict;
+use v5.14;
 use warnings;
 
 use parent 'DBIx::Class::ResultSet';
@@ -15,7 +13,7 @@ use Ref::Util qw/ is_plain_arrayref is_plain_hashref is_plain_scalarref /;
 
 use namespace::clean;
 
-our $VERSION = 'v0.3.2';
+our $VERSION = 'v0.4.0';
 
 
 sub _resolved_attrs {
@@ -84,7 +82,7 @@ DBIx::Class::Helper::TableSample - Add support for tablesample clauses
 
 =head1 VERSION
 
-version v0.3.2
+version v0.4.0
 
 =head1 SYNOPSIS
 
@@ -237,6 +235,16 @@ Not all databases support table sampling, and those that do may have
 different restrictions.  You should consult your database
 documentation.
 
+=head1 SUPPORT FOR OLDER PERL VERSIONS
+
+Since v0.4.0, the this module requires Perl v5.14 or later.
+
+Future releases may only support Perl versions released in the last ten years.
+
+If you need this module on Perl v5.10, please use one of the v0.3.x
+versions of this module.  Significant bug or security fixes may be
+backported to those versions.
+
 =head1 SEE ALSO
 
 L<DBIx::Class>
@@ -264,7 +272,7 @@ Library L<https://www.sciencephoto.com>.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2019-2022 by Robert Rothenberg.
+This software is Copyright (c) 2019-2023 by Robert Rothenberg.
 
 This is free software, licensed under:
 
